@@ -55,7 +55,7 @@ class MelodicImage(fslimage.Image):
         """
 
         if op.isdir(path):
-            path = op.join(path, 'melodic_IC')
+            path = melanalysis.getICFile(path)
 
         if not melanalysis.isMelodicImage(path):
             raise ValueError('{} does not appear to be a '
@@ -77,7 +77,7 @@ class MelodicImage(fslimage.Image):
             dataImage = fslimage.Image(dataFile,
                                        loadData=False,
                                        calcRange=False)
-            if dataImage.ndims >= 4:
+            if dataImage.ndim >= 4:
                 self.__tr = dataImage.pixdim[3]
 
 
