@@ -93,6 +93,14 @@ def test_flirt():
         assert checkResult(result.stdout[0], *expected)
 
 
+def test_epi_reg():
+    with asrt.disabled(), run.dryrun(), mockFSLDIR(bin=('epi_reg',)) as fsldir:
+        epi_reg  = op.join(fsldir, 'bin', 'epi_reg')
+        result   = fw.epi_reg('epi', 't1', 't1brain', 'out')
+        expected = epi_reg + ' --epi=epi --t1=t1 --t1brain=t1brain --out=out'
+        assert result.stdout[0] == expected
+
+
 def test_applyxfm():
     with asrt.disabled(), run.dryrun(), mockFSLDIR(bin=('flirt',)) as fsldir:
         flirt    = op.join(fsldir, 'bin', 'flirt')
@@ -291,14 +299,15 @@ def test_fslmaths():
             .fillh().ero().dilM().dilF().add('addim').sub('subim') \
             .mul('mulim').div('divim').mas('masim').rem('remim')   \
             .thr('thrim').uthr('uthrim').inm('inmim').bptf(1, 10) \
-            .smooth(sigma=6).run('output')
+            .smooth(sigma=6).kernel('3D').fmeanu().run('output')
 
         expected = [cmd, 'input',
                     '-abs', '-bin', '-binv', '-recip', '-Tmean', '-Tstd',
                     '-Tmin', '-Tmax', '-fillh', '-ero', '-dilM', '-dilF',
                     '-add addim', '-sub subim', '-mul mulim', '-div divim',
                     '-mas masim', '-rem remim', '-thr thrim', '-uthr uthrim',
-                    '-inm inmim', '-bptf 1 10', '-s 6', 'output']
+                    '-inm inmim', '-bptf 1 10', '-s 6', '-kernel 3D', '-fmeanu',
+                    'output']
         expected = ' '.join(expected)
 
         assert result.stdout[0] == expected
